@@ -1,11 +1,9 @@
 package MIME::Detect::Type;
-use strict;
+use 5.020;
 use Moo 2;
-use Filter::signatures;
-use feature 'signatures';
-no warnings 'experimental::signatures';
+use experimental 'signatures';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 =head1 NAME
 
